==> kdevelop-3.2.0.tar.bz2: kdevelop-3.2.0/languages/java/JavaTokenTypes.hpp <==
#ifndef INC_JavaTokenTypes_hpp_
#define INC_JavaTokenTypes_hpp_

/* $ANTLR 2.7.2: "java.g" -> "JavaTokenTypes.hpp"$ */
struct JavaTokenTypes {
	enum {
		EOF_ = 1,
		BLOCK = 4,
		MODIFIERS = 5,
		OBJBLOCK = 6,
		SLIST = 7,
		CTOR_DEF = 8,
		METHOD_DEF = 9,
		VARIABLE_DEF = 10,
		INSTANCE_INIT = 11,
		STATIC_INIT = 12,
		TYPE = 13,
		CLASS_DEF = 14,
		INTERFACE_DEF = 15,
		PACKAGE_DEF = 16,
		ARRAY_DECLARATOR = 17,
		EXTENDS_CLAUSE = 18,
		IMPLEMENTS_CLAUSE = 19,
		PARAMETERS = 20,
		PARAMETER_DEF = 21,
		LABELED_STAT = 22,
		TYPECAST = 23,
		INDEX_OP = 24,
		POST_INC = 25,
		POST_DEC = 26,
		METHOD_CALL = 27,
		EXPR = 28,
		ARRAY_INIT = 29,
		IMPORT = 30,
		UNARY_MINUS = 31,
		UNARY_PLUS = 32,
		CASE_GROUP = 33,
		ELIST = 34,
		FOR_INIT = 35,
		FOR_CONDITION = 36,
		FOR_ITERATOR = 37,
		EMPTY_STAT = 38,
		FINAL = 39,
		ABSTRACT = 40,
		STRICTFP = 41,
		SUPER_CTOR_CALL = 42,
		CTOR_CALL = 43,
		LITERAL_package = 44,
		SEMI = 45,
		LITERAL_import = 46,
		LBRACK = 47,
		RBRACK = 48,
		LITERAL_void = 49,
		LITERAL_boolean = 50,
		LITERAL_byte = 51,
		LITERAL_char = 52,
		LITERAL_short = 53,
		LITERAL_int = 54,
		LITERAL_float = 55,
		LITERAL_long = 56,
		LITERAL_double = 57,
		IDENT = 58,
		DOT = 59,
		STAR = 60,
		LITERAL_private = 61,
		LITERAL_public = 62,
		LITERAL_protected = 63,
		LITERAL_static = 64,
		LITERAL_transient = 65,
		LITERAL_native = 66,
		LITERAL_threadsafe = 67,
		LITERAL_synchronized = 68,
		LITERAL_volatile = 69,
		LITERAL_class = 70,
		LITERAL_extends = 71,
		LITERAL_interface = 72,
		LCURLY = 73,
		RCURLY = 74,
		COMMA = 75,
		LITERAL_implements = 76,
		LPAREN = 77,
		RPAREN = 78,
		LITERAL_this = 79,
		LITERAL_super = 80,
		ASSIGN = 81,
		LITERAL_throws = 82,
		COLON = 83,
		LITERAL_if = 84,
		LITERAL_else = 85,
		LITERAL_for = 86,
		LITERAL_while = 87,
		LITERAL_do = 88,
		LITERAL_break = 89,
		LITERAL_continue = 90,
		LITERAL_return = 91,
		LITERAL_switch = 92,
		LITERAL_throw = 93,
		LITERAL_case = 94,
		LITERAL_default = 95,
		LITERAL_try = 96,
		LITERAL_finally = 97,
		LITERAL_catch = 98,
		PLUS_ASSIGN = 99,
		MINUS_ASSIGN = 100,
		STAR_ASSIGN = 101,
		DIV_ASSIGN = 102,
		MOD_ASSIGN = 103,
		SR_ASSIGN = 104,
		BSR_ASSIGN = 105,
		SL_ASSIGN = 106,
		BAND_ASSIGN = 107,
		BXOR_ASSIGN = 108,
		BOR_ASSIGN = 109,
		QUESTION = 110,
		LOR = 111,
		LAND = 112,
		BOR = 113,
		BXOR = 114,
		BAND = 115,
		NOT_EQUAL = 116,
		EQUAL = 117,
		LT_ = 118,
		GT = 119,
		LE = 120,
		GE = 121,
		LITERAL_instanceof = 122,
		SL = 123,
		SR = 124,
		BSR = 125,
		PLUS = 126,
		MINUS = 127,
		DIV = 128,
		MOD = 129,
		INC = 130,
		DEC = 131,
		BNOT = 132,
		LNOT = 133,
		LITERAL_true = 134,
		LITERAL_false = 135,
		LITERAL_null = 136,
		LITERAL_new = 137,
		NUM_INT = 138,
		CHAR_LITERAL = 139,
		STRING_LITERAL = 140,
		NUM_FLOAT = 141,
		NUM_LONG = 142,
		NUM_DOUBLE = 143,
		WS = 144,
		SL_COMMENT = 145,
		ML_COMMENT = 146,
		ESC = 147,
		HEX_DIGIT = 148,
		VOCAB = 149,
		EXPONENT = 150,
		FLOAT_SUFFIX = 151,
		NULL_TREE_LOOKAHEAD = 3
	};
};
#endif /*INC_JavaTokenTypes_hpp_*/

==> kdevelop-3.4.0.tar.bz2: kdevelop-3.4.0/languages/java/JavaTokenTypes.hpp <==
#ifndef INC_JavaTokenTypes_hpp_
#define INC_JavaTokenTypes_hpp_

/* $ANTLR 2.7.7 (20061129): "java.g" -> "JavaTokenTypes.hpp"$ */

#ifndef CUSTOM_API
# define CUSTOM_API
#endif

#ifdef __cplusplus
struct CUSTOM_API JavaTokenTypes {
#endif
	enum {
		EOF_ = 1,
		BLOCK = 4,
		MODIFIERS = 5,
		OBJBLOCK = 6,
		SLIST = 7,
		CTOR_DEF = 8,
		METHOD_DEF = 9,
		VARIABLE_DEF = 10,
		INSTANCE_INIT = 11,
		STATIC_INIT = 12,
		TYPE = 13,
		CLASS_DEF = 14,
		INTERFACE_DEF = 15,
		PACKAGE_DEF = 16,
		ARRAY_DECLARATOR = 17,
		EXTENDS_CLAUSE = 18,
		IMPLEMENTS_CLAUSE = 19,
		PARAMETERS = 20,
		PARAMETER_DEF = 21,
		LABELED_STAT = 22,
		TYPECAST = 23,
		INDEX_OP = 24,
		POST_INC = 25,
		POST_DEC = 26,
		METHOD_CALL = 27,
		EXPR = 28,
		ARRAY_INIT = 29,
		IMPORT = 30,
		UNARY_MINUS = 31,
		UNARY_PLUS = 32,
		CASE_GROUP = 33,
		ELIST = 34,
		FOR_INIT = 35,
		FOR_CONDITION = 36,
		FOR_ITERATOR = 37,
		EMPTY_STAT = 38,
		FINAL = 39,
		ABSTRACT = 40,
		STRICTFP = 41,
		SUPER_CTOR_CALL = 42,
		CTOR_CALL = 43,
		LITERAL_package = 44,
		SEMI = 45,
		LITERAL_import = 46,
		LBRACK = 47,
		RBRACK = 48,
		LITERAL_void = 49,
		LITERAL_boolean = 50,
		LITERAL_byte = 51,
		LITERAL_char = 52,
		LITERAL_short = 53,
		LITERAL_int = 54,
		LITERAL_float = 55,
		LITERAL_long = 56,
		LITERAL_double = 57,
		IDENT = 58,
		DOT = 59,
		STAR = 60,
		LITERAL_private = 61,
		LITERAL_public = 62,
		LITERAL_protected = 63,
		LITERAL_static = 64,
		LITERAL_transient = 65,
		LITERAL_native = 66,
		LITERAL_threadsafe = 67,
		LITERAL_synchronized = 68,
		LITERAL_volatile = 69,
		LITERAL_class = 70,
		LITERAL_extends = 71,
		LITERAL_interface = 72,
		LCURLY = 73,
		RCURLY = 74,
		COMMA = 75,
		LITERAL_implements = 76,
		LPAREN = 77,
		RPAREN = 78,
		LITERAL_this = 79,
		LITERAL_super = 80,
		ASSIGN = 81,
		LITERAL_throws = 82,
		COLON = 83,
		LITERAL_if = 84,
		LITERAL_else = 85,
		LITERAL_for = 86,
		LITERAL_while = 87,
		LITERAL_do = 88,
		LITERAL_break = 89,
		LITERAL_continue = 90,
		LITERAL_return = 91,
		LITERAL_switch = 92,
		LITERAL_throw = 93,
		LITERAL_case = 94,
		LITERAL_default = 95,
		LITERAL_try = 96,
		LITERAL_finally = 97,
		LITERAL_catch = 98,
		PLUS_ASSIGN = 99,
		MINUS_ASSIGN = 100,
		STAR_ASSIGN = 101,
		DIV_ASSIGN = 102,
		MOD_ASSIGN = 103,
		SR_ASSIGN = 104,
		BSR_ASSIGN = 105,
		SL_ASSIGN = 106,
		BAND_ASSIGN = 107,
		BXOR_ASSIGN = 108,
		BOR_ASSIGN = 109,
		QUESTION = 110,
		LOR = 111,
		LAND = 112,
		BOR = 113,
		BXOR = 114,
		BAND = 115,
		NOT_EQUAL = 116,
		EQUAL = 117,
		LT_ = 118,
		GT = 119,
		LE = 120,
		GE = 121,
		LITERAL_instanceof = 122,
		SL = 123,
		SR = 124,
		BSR = 125,
		PLUS = 126,
		MINUS = 127,
		DIV = 128,
		MOD = 129,
		INC = 130,
		DEC = 131,
		BNOT = 132,
		LNOT = 133,
		LITERAL_true = 134,
		LITERAL_false = 135,
		LITERAL_null = 136,
		LITERAL_new = 137,
		NUM_INT = 138,
		CHAR_LITERAL = 139,
		STRING_LITERAL = 140,
		NUM_FLOAT = 141,
		NUM_LONG = 142,
		NUM_DOUBLE = 143,
		WS = 144,
		SL_COMMENT = 145,
		ML_COMMENT = 146,
		ESC = 147,
		HEX_DIGIT = 148,
		VOCAB = 149,
		EXPONENT = 150,
		FLOAT_SUFFIX = 151,
		NULL_TREE_LOOKAHEAD = 3
	};
#ifdef __cplusplus
};
#endif
#endif /*INC_JavaTokenTypes_hpp_*/
